==> react-common-bootstrap-2.0.63.tgz: package/list/TableSearch.js <==
import React, { useMemo, useState } from 'react';
import { CustomFormField } from '../form';
const TableSearch = ({
  items = [],
  fields = [],
  filter = (item, search) => true,
  editItem = null,
  deleteItem = null,
  actions = [],
  hideSearch = false,
  rowTemplate = null
}) => {
  const [search, setSearch] = useState('');
  const allActions = useMemo(() => {
    const actionsCopy = [...actions];
    if (editItem != null) {
      actionsCopy.push(item => /*#__PURE__*/React.createElement("span", {
        className: "mdi mdi-pencil mdi-24px clickable text-primary",
        onClick: () => editItem(item)
      }));
    }
    if (deleteItem != null) {
      actionsCopy.push(item => /*#__PURE__*/React.createElement("span", {
        className: "mdi mdi-delete mdi-24px clickable text-danger",
        onClick: () => deleteItem(item)
      }));
    }
    return actionsCopy;
  }, [actions, editItem, deleteItem]);
  const filteredItems = useMemo(() => items.filter(item => filter(item, search)), [items, search]);
  return /*#__PURE__*/React.createElement("div", {
    className: "table-search"
  }, !hideSearch && /*#__PURE__*/React.createElement(CustomFormField, {
    label: "Rechercher",
    value: search,
    onChange: value => setSearch(value)
  }), /*#__PURE__*/React.createElement("table", {
    className: "table"
  }, /*#__PURE__*/React.createElement("thead", null, /*#__PURE__*/React.createElement("tr", null, fields.map((field, index) => /*#__PURE__*/React.createElement(React.Fragment, {
    key: index
  }, /*#__PURE__*/React.createElement("th", null, field.label))), allActions.length > 0 && /*#__PURE__*/React.createElement("th", null))), /*#__PURE__*/React.createElement("tbody", null, filteredItems.map((item, i) => rowTemplate != null ? rowTemplate(item) : /*#__PURE__*/React.createElement("tr", {
    key: i
  }, fields.map((field, j) => /*#__PURE__*/React.createElement("td", {
    key: j
  }, field.get(item))), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement("div", {
    className: "flex end spaced-inline"
  }, allActions.map((action, index) => /*#__PURE__*/React.createElement(React.Fragment, {
    key: index
  }, action(item))))))))));
};
export default TableSearch;

==> react-common-bootstrap-2.0.64.tgz: package/list/TableSearch.js <==
import React, { useMemo, useState } from 'react';
import { CustomFormField } from '../form';
const TableSearch = ({
  items = [],
  fields = [],
  filter = (item, search) => true,
  editItem = null,
  deleteItem = null,
  actions = [],
  hideSearch = false,
  rowTemplate = null
}) => {
  const [search, setSearch] = useState('');
  const allActions = useMemo(() => {
    const actionsCopy = [...actions];
    if (editItem != null) {
      actionsCopy.push(item => /*#__PURE__*/React.createElement("span", {
        className: "mdi mdi-pencil mdi-24px clickable text-primary",
        onClick: () => editItem(item)
      }));
    }
    if (deleteItem != null) {
      actionsCopy.push(item => /*#__PURE__*/React.createElement("span", {
        className: "mdi mdi-delete mdi-24px clickable text-danger",
        onClick: () => deleteItem(item)
      }));
    }
    return actionsCopy;
  }, [actions, editItem, deleteItem]);
  const filteredItems = useMemo(() => items.filter(item => filter(item, search)), [items, search]);
  return /*#__PURE__*/React.createElement("div", {
    className: "table-search"
  }, !hideSearch && /*#__PURE__*/React.createElement(CustomFormField, {
    label: "Rechercher",
    value: search,
    onChange: value => setSearch(value)
  }), /*#__PURE__*/React.createElement("table", {
    className: "table"
  }, /*#__PURE__*/React.createElement("thead", null, /*#__PURE__*/React.createElement("tr", null, fields.map((field, index) => /*#__PURE__*/React.createElement(React.Fragment, {
    key: index
  }, /*#__PURE__*/React.createElement("th", null, field.label))), allActions.length > 0 && /*#__PURE__*/React.createElement("th", null))), /*#__PURE__*/React.createElement("tbody", null, filteredItems.map((item, i) => rowTemplate != null ? /*#__PURE__*/React.createElement(React.Fragment, {
    key: i
  }, "rowTemplate(item)") : /*#__PURE__*/React.createElement("tr", {
    key: i
  }, fields.map((field, j) => /*#__PURE__*/React.createElement("td", {
    key: j
  }, field.get(item))), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement("div", {
    className: "flex end spaced-inline"
  }, allActions.map((action, index) => /*#__PURE__*/React.createElement(React.Fragment, {
    key: index
  }, action(item))))))))));
};
export default TableSearch;
